@@ -1,6 +1,6 @@
 <?php
 /* 
-V5.07 18 Dec 2008   (c) 2000-2008 John Lim (jlim#natsoft.com). All rights reserved.
+V5.09 25 June 2009   (c) 2000-2009 John Lim (jlim#natsoft.com). All rights reserved.
 Released under both BSD license and Lesser GPL library license. 
 Whenever there is any discrepancy between the two licenses, 
 the BSD license will take precedence. See License.txt. 
@@ -26,7 +26,6 @@ class  ADODB_ado_access extends ADODB_ado {
 	var $fmtTimeStamp = "#Y-m-d h:i:sA#";// note no comma
 	var $sysDate = "FORMAT(NOW,'yyyy-mm-dd')";
 	var $sysTimeStamp = 'NOW';
-	var $hasTransactions = false;
 	var $upperCase = 'ucase';
 	
 	function ADODB_ado_access()
@@ -34,11 +33,11 @@ class  ADODB_ado_access extends ADODB_ado {
 		$this->ADODB_ado();
 	}
 	
-	function BeginTrans() { return false;}
+	/*function BeginTrans() { return false;}
 	
 	function CommitTrans() { return false;}
 	
-	function RollbackTrans() { return false;}
+	function RollbackTrans() { return false;}*/
 
 }
 
